/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: AbsBeanEventListener.java 4389 2008-12-15 13:48:57Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.event.listeners;

import org.ow2.util.ee.event.types.AbstractEvent;
import org.ow2.util.event.api.EventPriority;
import org.ow2.util.event.api.IEvent;
import org.ow2.util.event.api.IEventListener;

/**
 * Abstract event listener.
 * @author eyindanga
 */
public abstract class AbsBeanEventListener implements IEventListener {
    /**
     * Event provider filter.
     */
    private String eventProviderFilter = null;

    /**
     * Contructor.
     * @param providerFilter provider filter
     */
    public AbsBeanEventListener(final String eventProviderFilter) {
        this.eventProviderFilter = eventProviderFilter;
    }

    /*
     * (non-Javadoc)
     * @see org.ow2.util.event.api.IEventListener#accept(org.ow2.util.event.api.IEvent)
     */
    public boolean accept(final IEvent event) {
        try {
            return ((AbstractEvent) event).getEventProviderFilter().matches(eventProviderFilter);
        } catch (Exception e) {
            return false;
        }

    }

    /*
     * (non-Javadoc)
     * @see org.ow2.util.event.api.IEventListener#getPriority()
     */
    public EventPriority getPriority() {
        return EventPriority.ASYNC_HIGH;
    }

    /*
     * (non-Javadoc)
     * @see org.ow2.util.event.api.IEventListener#handle(org.ow2.util.event.api.IEvent)
     */
    public abstract void handle(final IEvent event);

    /**
     * @return the eventProviderFilter
     */
    public String getEventProviderFilter() {
        return eventProviderFilter;
    }

    /**
     * @param eventProviderFilter the eventProviderFilter to set
     */
    public void setEventProviderFilter(final String eventProviderFilter) {
        this.eventProviderFilter = eventProviderFilter;
    }

}
